@@ -31,7 +31,7 @@ namespace Akonadi
 
 class IncidenceChanger;
 
-class TodoPurger::Private : public QObject
+class Q_DECL_HIDDEN TodoPurger::Private : public QObject
 {
     Q_OBJECT
 public:
@@ -48,7 +48,9 @@ public:
 
 public Q_SLOTS:
     void onCalendarLoaded(bool success, const QString &message);
-    void onItemsDeleted(int changeId, const QVector<Akonadi::Item::Id> &deletedItems, Akonadi::IncidenceChanger::ResultCode, const QString &message);
+    void onItemsDeleted(int changeId, const QVector<Akonadi::Item::Id> &deletedItems,
+                        Akonadi::IncidenceChanger::ResultCode,
+                        const QString &message);
 private:
     TodoPurger *const q;
 };
